@@ -46,16 +46,10 @@
 #include <openssl/x509v3.h>
 #include <openssl/dh.h>
 #include <openssl/bn.h>
-#if OPENSSL_VERSION_NUMBER > 0x2FFFFFFFL && !defined(LIBRESSL_VERSION_NUMBER)
+#ifndef LIBRESSL_VERSION_NUMBER
 #include <openssl/provider.h>
 #endif
-/* Avoid tripping over an engine build installed globally and detected
- * when the user points at an explicit non-engine flavor of OpenSSL
- */
-#ifndef OPENSSL_NO_ENGINE
-#include <openssl/engine.h>
-extern ENGINE *tcn_ssl_engine;
-#endif
+#include <openssl/core_names.h>
 
 #ifndef RAND_MAX
 #include <limits.h>
@@ -257,7 +251,6 @@ typedef struct tcn_ssl_ctxt_t tcn_ssl_ctxt_t;
 typedef struct {
     char            password[SSL_MAX_PASSWORD_LEN];
     const char     *prompt;
-    tcn_callback_t cb;
 } tcn_pass_cb_t;
 
 extern tcn_pass_cb_t tcn_password_callback;
@@ -384,9 +377,9 @@ int         SSL_password_callback(char *, int, int, void *);
 void        SSL_BIO_close(BIO *);
 void        SSL_BIO_doref(BIO *);
 DH         *SSL_get_dh_params(unsigned keylen);
-DH         *SSL_dh_GetParamFromFile(const char *);
+EVP_PKEY   *SSL_dh_GetParamFromFile(const char *);
 #ifdef HAVE_ECC
-EC_GROUP   *SSL_ec_GetParamFromFile(const char *);
+int         SSL_ec_GetParamFromFile(const char *);
 #endif
 DH         *SSL_callback_tmp_DH(SSL *, int, int);
 void        SSL_callback_handshake(const SSL *, int, int);
