@@ -38,18 +38,10 @@
 #include <pthread.h>
 #endif
 
-#ifdef TCN_DO_STATISTICS
-extern void sp_poll_dump_statistics();
-extern void sp_network_dump_statistics();
-extern void ssl_network_dump_statistics();
-#endif
-
 apr_pool_t *tcn_global_pool = NULL;
 static JavaVM     *tcn_global_vm = NULL;
 
 static jclass    jString_class;
-static jclass    jFinfo_class;
-static jclass    jAinfo_class;
 static jmethodID jString_init;
 static jmethodID jString_getBytes;
 
@@ -70,12 +62,12 @@ JNIEXPORT jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
     tcn_global_vm = vm;
     env           = (JNIEnv *)ppe;
     /* Before doing anything else check if we have a valid
-     * APR version. We need version 1.6.3 as minimum.
+     * APR version. We need version 1.7.0 as minimum.
      */
     apr_version(&apv);
     apvn = apv.major * 1000 + apv.minor * 100 + apv.patch;
-    if (apvn < 1603) {
-        tcn_Throw(env, "Unsupported APR version %s: this tcnative requires at least 1.6.3",
+    if (apvn < 1700) {
+        tcn_Throw(env, "Unsupported APR version %s: this tcnative requires at least 1.7.0",
                   apr_version_string());
         return JNI_ERR;
     }
@@ -87,19 +79,6 @@ JNIEXPORT jint JNICALL JNI_OnLoad(JavaVM *vm, void *reserved)
     TCN_GET_METHOD(env, jString_class, jString_getBytes,
                    "getBytes", "()[B", JNI_ERR);
 
-    TCN_LOAD_CLASS(env, jFinfo_class, TCN_FINFO_CLASS, JNI_OK);
-    if (jFinfo_class) {
-        if (tcn_load_finfo_class(env, jFinfo_class) != APR_SUCCESS) {
-            return JNI_ERR;
-        }
-    }
-
-    TCN_LOAD_CLASS(env, jAinfo_class, TCN_AINFO_CLASS, JNI_OK);
-    if (jAinfo_class) {
-        if (tcn_load_ainfo_class(env, jAinfo_class) != APR_SUCCESS) {
-            return JNI_ERR;
-        }
-    }
 #ifdef WIN32
     {
         char *ppid = getenv(TCN_PARENT_IDE);
@@ -128,8 +107,6 @@ JNIEXPORT void JNICALL JNI_OnUnload(JavaVM *vm, void *reserved)
     if (tcn_global_pool) {
         env  = (JNIEnv *)ppe;
         TCN_UNLOAD_CLASS(env, jString_class);
-        TCN_UNLOAD_CLASS(env, jFinfo_class);
-        TCN_UNLOAD_CLASS(env, jAinfo_class);
         apr_terminate();
     }
 }
@@ -265,26 +242,11 @@ TCN_IMPLEMENT_CALL(void, Library, terminate)(TCN_STDARGS)
     if (tcn_global_pool) {
         apr_pool_t *p = tcn_global_pool;
         tcn_global_pool = NULL;
-#ifdef TCN_DO_STATISTICS
-        fprintf(stderr, "APR Statistical data ....\n");
-#endif
         apr_pool_destroy(p);
-#ifdef TCN_DO_STATISTICS
-        sp_poll_dump_statistics();
-        sp_network_dump_statistics();
-        ssl_network_dump_statistics();
-        fprintf(stderr, "APR Terminated\n");
-#endif
         apr_terminate();
     }
 }
 
-TCN_IMPLEMENT_CALL(jlong, Library, globalPool)(TCN_STDARGS)
-{
-    UNREFERENCED_STDARGS;
-    return P2J(tcn_global_pool);
-}
-
 TCN_IMPLEMENT_CALL(jint, Library, version)(TCN_STDARGS, jint what)
 {
     apr_version_t apv;
