@@ -19,7 +19,6 @@
 
 #include "tcn.h"
 
-#ifdef HAVE_OPENSSL
 #include "apr_poll.h"
 #include "ssl_private.h"
 
@@ -127,32 +126,13 @@ int SSL_password_prompt(tcn_pass_cb_t *data)
 {
     int rv = 0;
     data->password[0] = '\0';
-    if (data->cb.obj) {
-        JNIEnv *e;
-        jobject  o;
-        jstring  prompt;
-        tcn_get_java_env(&e);
-        prompt = AJP_TO_JSTRING(data->prompt);
-        if ((o = (*e)->CallObjectMethod(e, data->cb.obj,
-                            data->cb.mid[0], prompt))) {
-            TCN_ALLOC_CSTRING(o);
-            if (J2S(o)) {
-                strncpy(data->password, J2S(o), SSL_MAX_PASSWORD_LEN);
-                data->password[SSL_MAX_PASSWORD_LEN-1] = '\0';
-                rv = (int)strlen(data->password);
-            }
-            TCN_FREE_CSTRING(o);
-        }
-    }
-    else {
 #ifdef WIN32
-        rv = WIN32_SSL_password_prompt(data);
+    rv = WIN32_SSL_password_prompt(data);
 #else
-        EVP_read_pw_string(data->password, SSL_MAX_PASSWORD_LEN,
-                           data->prompt, 0);
+    EVP_read_pw_string(data->password, SSL_MAX_PASSWORD_LEN,
+                       data->prompt, 0);
 #endif
-        rv = (int)strlen(data->password);
-    }
+    rv = (int)strlen(data->password);
     if (rv > 0) {
         /* Remove LF char if present */
         char *r = strchr(data->password, '\n');
@@ -201,58 +181,61 @@ int SSL_password_callback(char *buf, int bufsiz, int verify,
 **  Custom (EC)DH parameter support
 **  _________________________________________________________________
 */
-DH *SSL_dh_GetParamFromFile(const char *file)
+EVP_PKEY *SSL_dh_GetParamFromFile(const char *file)
 {
-    DH *dh = NULL;
+    EVP_PKEY *evp = NULL;
     BIO *bio;
 
     if ((bio = BIO_new_file(file, "r")) == NULL)
         return NULL;
-    dh = PEM_read_bio_DHparams(bio, NULL, NULL, NULL);
+    evp = PEM_read_bio_Parameters_ex(bio, NULL, NULL, NULL);
     BIO_free(bio);
-    return dh;
+    if (evp && !EVP_PKEY_is_a(evp, "DH")) {
+        EVP_PKEY_free(evp);
+        return NULL;
+    }
+    return evp;
 }
 
 #ifdef HAVE_ECC
-EC_GROUP *SSL_ec_GetParamFromFile(const char *file)
+int SSL_ec_GetParamFromFile(const char *file)
 {
-    EC_GROUP *group = NULL;
+    EVP_PKEY *evp = NULL;
     BIO *bio;
+    char curve_name[80];
 
     if ((bio = BIO_new_file(file, "r")) == NULL)
-        return NULL;
-    group = PEM_read_bio_ECPKParameters(bio, NULL, NULL, NULL);
+        return NID_undef;
+    evp = PEM_read_bio_Parameters_ex(bio, NULL, NULL, NULL);
     BIO_free(bio);
-    return (group);
+    if (evp && !EVP_PKEY_is_a(evp, "EC")) {
+        EVP_PKEY_free(evp);
+        return NID_undef;
+    }
+
+    OSSL_PARAM param[] = {
+        OSSL_PARAM_construct_utf8_string(OSSL_PKEY_PARAM_GROUP_NAME, curve_name, sizeof(curve_name)),
+        OSSL_PARAM_construct_end()
+    };
+
+    /* Query the curve name from the EVP_PKEY params object */
+    if (EVP_PKEY_get_params(evp, param) <= 0) {
+        EVP_PKEY_free(evp);
+        return NID_undef; /* Failed to retrieve the curve name */
+    }
+
+    /* Convert the curve name to the NID */
+    int nid = OBJ_sn2nid(curve_name);
+    if (nid == NID_undef) {
+        /* If the short name didn't resolve, try the long name */
+        nid = OBJ_ln2nid(curve_name);
+    }
+
+    EVP_PKEY_free(evp);
+    return nid; /* Returns the curve's NID, or NID_undef on failure */
 }
 #endif
 
-/*
- * Hand out standard DH parameters, based on the authentication strength
- */
-DH *SSL_callback_tmp_DH(SSL *ssl, int export, int keylen)
-{
-    EVP_PKEY *pkey = SSL_get_privatekey(ssl);
-    int type = pkey != NULL ? EVP_PKEY_base_id(pkey) : EVP_PKEY_NONE;
-
-    /*
-     * OpenSSL will call us with either keylen == 512 or keylen == 1024
-     * (see the definition of SSL_EXPORT_PKEYLENGTH in ssl_locl.h).
-     * Adjust the DH parameter length according to the size of the
-     * RSA/DSA private key used for the current connection, and always
-     * use at least 1024-bit parameters.
-     * Note: This may cause interoperability issues with implementations
-     * which limit their DH support to 1024 bit - e.g. Java 7 and earlier.
-     * In this case, SSLCertificateFile can be used to specify fixed
-     * 1024-bit DH parameters (with the effect that OpenSSL skips this
-     * callback).
-     */
-    if ((type == EVP_PKEY_RSA) || (type == EVP_PKEY_DSA)) {
-        keylen = EVP_PKEY_bits(pkey);
-    }
-    return SSL_get_dh_params(keylen);
-}
-
 /*
  * Read a file that optionally contains the server certificate in PEM
  * format, possibly followed by a sequence of CA certificates that
@@ -379,12 +362,8 @@ int SSL_callback_SSL_verify(int ok, X509_STORE_CTX *ctx)
                 }
                 else if (ocsp_response == OCSP_STATUS_UNKNOWN) {
                     errnum = X509_STORE_CTX_get_error(ctx);
-                    if (errnum != 0 && !(ocsp_soft_fail && errnum == X509_V_ERR_UNABLE_TO_GET_CRL)) {
+                    if (errnum != 0 && !(ocsp_soft_fail && errnum == X509_V_ERR_UNABLE_TO_GET_CRL))
                         ok = 0;
-                    } else {
-                        // Clear the store error else the handshake will fail with the APR connector
-                        X509_STORE_CTX_set_error(ctx, 0);
-                    }
                 }
             }
         }
@@ -997,7 +976,7 @@ static OCSP_RESPONSE *get_ocsp_response(apr_pool_t *p, char *url, OCSP_REQUEST *
     int ok = 0;
     apr_socket_t *apr_sock = NULL;
     apr_pool_t *mp;
-#if OPENSSL_VERSION_NUMBER < 0x30000000L || defined(LIBRESSL_VERSION_NUMBER)
+#ifdef LIBRESSL_VERSION_NUMBER
     if (OCSP_parse_url(url, &hostname, &c_port, &path, &use_ssl) == 0)
 #else
     if (OSSL_HTTP_parse_url(url, &use_ssl, NULL, &hostname, &c_port, NULL, &path, NULL, NULL) == 0)
@@ -1162,4 +1141,3 @@ static int ssl_ocsp_request(X509 *cert, X509 *issuer, X509_STORE_CTX *ctx, int t
 }
 
 #endif /* HAVE_OCSP */
-#endif /* HAVE_OPENSSL  */
